<?php
// This file is part of Moodle - http://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <http://www.gnu.org/licenses/>.

/**
 * Muestra el contenido de la página
 *
 * @package   local_decalogo
 * @copyright 2021 su nombre
 * @license   http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */

require_once('../../../config.php');
require_once($CFG->dirroot . '/user/externallib.php');



global $DB, $OUTPUT, $PAGE, $CFG, $USER;

require_login();

$isAdmin = is_siteadmin();



$PAGE->requires->js(new moodle_url($CFG->wwwroot . '/local/my_courses/js/index.js'));
$PAGE->requires->css(new moodle_url($CFG->wwwroot . '/local/my_courses/css/styles.css'));

mb_internal_encoding('UTF-8');

// Definimos nuestra página
$PAGE->set_url('/local/my_courses/pages/mycourses.php');
$PAGE->set_pagelayout('standard');

$settings_config = (array) get_config('local_my_courses');


echo $OUTPUT->header();

/**
 * Busqueda de cursos crear una propia
 */
//form de la busqueda por get
?>
<div class="">
    <form class="form-inline" action="" method="get">
        <input class="form-control mr-sm-2" type="search" placeholder="<?php echo get_string('searchcourses', 'local_my_courses'); ?>" aria-label="Search" name="q">
        <button class="btn  my-2 my-sm-0 regional-btn-search" type="submit"><?php echo get_string('search', 'local_my_courses'); ?></button>
        <?php //obtener el parameto buscado
        $data = (object) [
            'q' => '',
        ];
        ?>
        <button type="button" style="<?php echo (isset($_GET['q'])) ?  'display:block' :  'display:none'; ?>" class="regional-btn-search btn" id="btn-close" aria-label="Close" style="">
            <?php echo get_string('showall', 'local_my_courses'); ?>
        </button>
    </form>
</div>
<div class="local_my_courses-results-view">
    <?php

    // Verifica si se ha enviado un valor para 'q' en la URL (a través del formulario de búsqueda)
    if (isset($_GET['q'])) {
        // Asigna el valor de 'q' a la propiedad 'q' del objeto $data
        $data->q = $_GET['q'];
        if (isset($_GET['pageno'])) {
            $pageno = $_GET['pageno'];
        } else {
            $pageno = 1;
        }
        $no_of_records_per_page = 8;
        $offset = ($pageno-1) * $no_of_records_per_page;

        
        $total_pages_sql = "SELECT c.fullname  FROM mdl_course as c JOIN mdl_course_categories as cc on c.category = cc.id where c.fullname LIKE '%" . $data->q . "%' AND cc.name LIKE '%Mis cursos%'";
        $total_rows = $DB->get_records_sql($total_pages_sql);
        
        $total_pages = ceil(count($total_rows) / $no_of_records_per_page);
       
        $coursesSQl = "SELECT c.*, cc.name AS category_name FROM mdl_course as c JOIN mdl_course_categories as cc on c.category = cc.id where c.fullname LIKE '%" . $data->q . "%' AND cc.name LIKE '%Mis cursos%' LIMIT ". $offset.", ".$no_of_records_per_page."";
        $courses = $DB->get_records_sql($coursesSQl);

       

        if (!empty($_GET['q'])) { ?>
        
            <div class="category-container mt-4" id="category-container-search">
                <?php foreach ($courses as $course) {

                    //verifica si esta matriculado a los cursos
                    // $context = get_context_instance(CONTEXT_COURSE, $course->id);
                    $context = context_course::instance($course->id);
                    $enrrolluser = is_enrolled($context, $USER);

                    if ($enrrolluser || has_capability('moodle/site:config', $context)) {
                    //pinta los resultados de la consulta
        
                    $course_img = new core_course_list_element($course);

                    ?>
                    <div class="card-category">
                        <?php
                        /**
                         * 
                         * Carga de a imagen del curso si no tiene se carga un div en blanco
                         * 
                         */
                        if (!empty($course_img->get_course_overviewfiles())) {
                            foreach ($course_img->get_course_overviewfiles() as $file) {

                                if ($file->is_valid_image()) {
                                    $imagepath = '/' . $file->get_contextid() .
                                        '/' . $file->get_component() .
                                        '/' . $file->get_filearea() .
                                        $file->get_filepath() .
                                        $file->get_filename();
                                    $imageurl = file_encode_url(
                                        $CFG->wwwroot . '/pluginfile.php',
                                        $imagepath,
                                        false
                                    );
                                    ?>
                                    <div class="card-category__image">
                                        <a href="<?php echo $CFG->wwwroot . '/course/view.php?id=' . $course_img->id ?>">
                                            <img src="<?php echo $imageurl ?>" alt="course image" class="w-100 h-100 card-category__image_img">
                                        </a>
                                    </div>
                                    <?php
                                    // Usa la primera imagen ue encuentra
                                    break;
                                }
                            }
                        } else {
                            /**Imagen por defecto cuando no tienen imagen de curso */
                            ?>
                            <div class="card-category__not-image">
                                <a href="<?php echo $CFG->wwwroot . '/course/view.php?id=' . $course->id ?>">
                                    <img src="<?php echo '../pix/imagen-curso.svg' ?>" alt="course image"
                                        class="w-100 h-100 card-category__image_img">
                                </a>
                            </div>
                        <?php } ?>
                        <div class="mt-3 mb-3 card-category_info">
                            <a href="<?php echo $CFG->wwwroot . '/course/view.php?id=' . $course->id; ?>">
                                <?php echo $course->fullname; ?>
                            </a>
                            <p class="card-category_guide-category">
                                <?php echo $course->category_name; ?>
                            </p>
                            <?php $progress_course = core_completion\progress::get_course_progress_percentage($course); ?>

                            <div class="card-category_progress-text">
                                <?php
                                if (!is_null($progress_course)) {
                                    ?>
                                    <span>
                                        <?php
                                        $progress_percent = bcdiv($progress_course, '1', 2);
                                        echo ($progress_percent < 1) ? '0' : $progress_percent;
                                        ?>
                                        % complete
                                    </span>
                                <?php } else { ?>
                                    <div style="height:24px"></div>
                                <?php } ?>
                            </div>
                        </div>
                    </div>

                    <?php
                    }
                } 
                ?>
            
             <div style="width:100%">
                <ul class="pagination" id="pagination-content">
                        <li><a href="?q=<?php echo $_GET['q'] ?>&pageno=1"><?php echo get_string('first', 'local_my_courses'); ?></a></li>
                        <li class="<?php if($pageno <= 1){ echo 'disabled'; } ?>">
                            <a href="<?php if($pageno <= 1){ echo '#'; } else { echo "?q=".$_GET['q']."&pageno=".($pageno - 1); } ?>"><img src="<?php echo '../pix/chevron-right.svg' ?>" alt="course image"></a>
                        </li>
                        <li class="<?php if($pageno >= $total_pages){ echo 'disabled'; } ?>">
                            <a href="<?php if($pageno >= $total_pages){ echo '#'; } else { echo "?q=".$_GET['q']."&pageno=".($pageno + 1); } ?>"><img src="<?php echo '../pix/chevron-left.svg' ?>" alt="course image"></a>
                        </li>
                        <li><a href="?q=<?php echo $_GET['q'] ?>&pageno=<?php echo $total_pages; ?>"><?php echo get_string('last', 'local_my_courses'); ?></a></li>
                    </ul>
                </div>    
            </div>    
        <?php }
        
    } ?>

</div>
<?php

/**
 * Contenido de la categoria is cursos
 */
//obtengo las categorias
$categories = core_course_category::get_all();

foreach ($categories as $cat) {
    if ($cat->name == 'Mis cursos') {
        $cat_courses = core_course_category::get($cat->id);

        $courses_by_category = $cat_courses->get_courses();

        if (isset($_GET['pageno'])) {
            $pageno = $_GET['pageno'];
        } else {
            $pageno = 1;
        }
        $no_of_records_per_page = 8;
        $offset = ($pageno-1) * $no_of_records_per_page;
        
        $total_pages = ceil(count($courses_by_category) / $no_of_records_per_page);

        if (!empty($courses_by_category)) {

            ?>
        
            <div class="category-container mt-4" id="category-default">
                <?php
                $courses_by_category = array_chunk($courses_by_category, $no_of_records_per_page);

                foreach ($courses_by_category[$pageno - 1] as $guide) {

                    $context = context_course::instance($guide->id);
                    // $context = get_context_instance(CONTEXT_COURSE, $guide->id);
                    $enrrolluser = is_enrolled($context, $USER);


                    if ($enrrolluser || has_capability('moodle/site:config', $context)) {

                    
                    ?>
                    <div class="card-category">
                        <?php
                        /**
                         * 
                         * Carga de a imagen del curso si no tiene se carga un div en blanco
                         * 
                         */
                        if (!empty($guide->get_course_overviewfiles())) {
                            foreach ($guide->get_course_overviewfiles() as $file) {

                                if ($file->is_valid_image()) {
                                    $imagepath = '/' . $file->get_contextid() .
                                        '/' . $file->get_component() .
                                        '/' . $file->get_filearea() .
                                        $file->get_filepath() .
                                        $file->get_filename();
                                    $imageurl = file_encode_url(
                                        $CFG->wwwroot . '/pluginfile.php',
                                        $imagepath,
                                        false
                                    );
                                    ?>
                                    <div class="card-category__image">
                                        <a href="<?php echo $CFG->wwwroot . '/course/view.php?id=' . $guide->id ?>">
                                            <img src="<?php echo $imageurl ?>" alt="course image" class="card-category__image_img">
                                        </a>
                                    </div>
                                    <?php
                                    // Usa la primera imagen ue encuentra
                                    break;
                                }
                            }
                        } else {
                            /**Imagen por defecto cuando no tienen imagen de curso */

                            ?>
                            <div class="card-category__not-image">
                                <a href="<?php echo $CFG->wwwroot . '/course/view.php?id=' . $guide->id ?>">
                                    <img src="<?php echo '../pix/imagen-curso.svg' ?>" alt="course image" class=" card-category__image_img">

                                </a>
                            </div>
                            <?php
                        }
                        ?>

                        <div class="mt-3 mb-3 card-category_info">
                            <a href="<?php echo $CFG->wwwroot . '/course/view.php?id=' . $guide->id; ?>">
                                <?php echo $guide->fullname; ?>
                            </a>
                            <p class="card-category_guide-category">
                                <?php echo $cat->name; ?>
                            </p>
                            <?php $progress_course = core_completion\progress::get_course_progress_percentage($guide); ?>
                            <div class="card-category_progress-text">
                                <?php
                                if (!is_null($progress_course)) {
                                    ?>
                                    <span>
                                        <?php
                                        $progress_percent = bcdiv($progress_course, '1', 2);
                                        echo ($progress_percent < 1) ? '0' : $progress_percent;
                                        ?>
                                        % complete
                                    </span>
                                    <?php
                                } else {
                                    ?>
                                    <div style="height:24px">

                                    </div>
                                    <?php
                                }
                                ?>
                            </div>
                        </div>
                    </div>

                    <?php
                    }
                }
                ?>
                <div style="width:100%">
                <ul class="pagination" id="pagination-content">
                    <li><a href="?pageno=1"><?php echo get_string('first', 'local_my_courses'); ?></a></li>
                    <li class="<?php if($pageno <= 1){ echo 'disabled'; } ?>">
                        <a href="<?php if($pageno <= 1){ echo '#'; } else { echo "?pageno=".($pageno - 1); } ?>"><img src="<?php echo '../pix/chevron-right.svg' ?>" alt="course image"></a>
                    </li>
                    <li class="<?php if($pageno >= $total_pages){ echo 'disabled'; } ?>">
                        <a href="<?php if($pageno >= $total_pages){ echo '#'; } else { echo "?pageno=".($pageno + 1); } ?>"><img src="<?php echo '../pix/chevron-left.svg' ?>" alt="course image"></a>
                    </li>
                    <li><a href="?pageno=<?php echo $total_pages; ?>"><?php echo get_string('last', 'local_my_courses'); ?></a></li>
                </ul>
            </div>
            
           
            <?php
        } else {
            /**
             * no muestra nada si no esta mtriculado en el curso
             */
        }
      
    }
}


echo $OUTPUT->footer();


?>